# LibRapid Examples

This directory contains a simple set of examples that make use of the librapid library in C++ and Python.

To compile the C++ examples, just use your favourite compiler and ensure it can access the LibRapid C++ library. For
example, if you ``git clone``ed LibRapid into the directory ``C:/opt/librapid``, you could
run: ``g++ test_program.cpp -I C:/opt/librapid/librapid``

To run the python programs, either open it in IDLE (or another IDE, such as Visual Studio Code) and press start, or run
the command ``python test_program.py``
